@@ -51,7 +51,7 @@ class EndpointSlice(NamespacedResource):
         self.endpoints = endpoints
         self.ports = ports
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             if not (self.address_type and self.endpoints):
